@@ -7,5 +7,8 @@ __all__ = (
 
 def api_response(data, count=None, pagination: BasePagination = None) -> dict:
     if isinstance(data, (list, tuple)):
-        return dict(meta=dict(count=count, **pagination.params), result=data)
+        return dict(
+            meta=pagination.schema(count=count, **pagination.params),
+            result=data
+        )
     return data
